<?php

namespace AustraliaPost\Extensions\Business\Endpoints;

use AustraliaPost\Extensions\Business\API\Business;
use AustraliaPost\Extensions\Business\API\Wrapper\Label;
use AustraliaPost\Extensions\Business\Helpers\Utilities;
use WC_Order;

class Generate_Labels_Endpoint extends Abstract_Endpoint {

	const LABELS_LABELS_META_KEY = '_labels_pro_labels';

	public function callback( $data ) {

		$label_request = $this->get_label_request($data);

		$label_response = (new Business())->generate_label($label_request);

		if (isset($label_response['errors'])) {
			$this->abort($label_response['errors']);
		}

		if ( isset($label_response['labels']) ) {
			$order = $this->get_order($data);
			$order->update_meta_data(self::LABELS_LABELS_META_KEY, Utilities::_json_encode($label_response));
		}

		return $label_response;
	}

	public function action() {
		return 'generate_labels';
	}

	/**
	 * @param $data
	 *
	 * @return Label
	 */
	private function get_label_request( $data ) {

		$order = $this->get_order($data);
		$shipments = $order->get_meta(Create_Shipments_Endpoint::LABELS_SHIPMENTS_META_KEY);

		if (!$shipments) {
			$this->abort('Something went wrong');
		}

		$shipments = json_decode($shipments, true);

		$label_request = new Label();

		$label_request->setIsBranded(Utilities::get_method_setting('label_branded') !== 'no');
		$label_request->setLabelLayouts(Utilities::get_method_setting('label_layout'));

		foreach ($shipments as $shipment) {

			$label_request->addShipment( [
				'shipment_id' => $shipment['shipment_id'],
				'items'       => $shipment['items']
			] );
		}

		return $label_request;
	}

}
